@@ -12,9 +12,8 @@ git config --global user.email "support@bigswitch.com"
 
 # get version info from tags
 # git fetch --tags
-# NOTE update refs/tags/12.*.* according to version string for each branch
-CURR_VERSION=`git for-each-ref refs/tags/12.*.* --sort="-*committerdate" --format="%(refname:short)" --count=1`
-CURR_SUBJECT=`git for-each-ref refs/tags/12.*.* --sort="-*committerdate" --format="%(subject)" --count=1`
+CURR_VERSION=`git for-each-ref refs/tags/$GIT_TAG_REGEX --sort="-*committerdate" --format="%(refname:short)" --count=1`
+CURR_SUBJECT=`git for-each-ref refs/tags/$GIT_TAG_REGEX --sort="-*committerdate" --format="%(subject)" --count=1`
 
 echo 'CURR_VERSION=' $CURR_VERSION
 echo 'CURR_SUBJECT=' $CURR_SUBJECT
@@ -26,7 +25,7 @@ python setup.py sdist
 twine upload dist/* -r pypi -s -i "Big Switch Networks" || true
 # delay of 10 seconds
 sleep 10
-sudo -H pip install --upgrade networking-bigswitch==$CURR_VERSION
+pip install --upgrade networking-bigswitch==$CURR_VERSION
 if [ "$?" -eq "0" ]
 then
   echo "PYPI upload successful."
@@ -34,7 +33,7 @@ else
   echo "PYPI upload FAILED. Check the logs."
 fi
 # remove the package
-sudo -H pip uninstall -y networking-bigswitch
+pip uninstall -y networking-bigswitch
 
 # revert the permissions
 chown -R $OUTER_UID:$OUTER_GID /networking-bigswitch
