@@ -28,12 +28,10 @@ from neutron_lib import context as q_context
 from oslo_config import cfg
 from oslo_log import log
 from oslo_service import loopingcall
-from oslo_utils import excutils
 
 from networking_bigswitch.plugins.bigswitch import config as pl_config
 from networking_bigswitch.plugins.bigswitch.i18n import _LI
 from neutron.agent.common import ovs_lib
-from neutron.agent.linux import utils
 from neutron.agent import rpc as agent_rpc
 from neutron.agent import securitygroups_rpc as sg_rpc
 from neutron.api.rpc.handlers import securitygroups_rpc as api_sg_rpc
@@ -42,100 +40,9 @@ from neutron.extensions import securitygroup as ext_sg
 
 eventlet.monkey_patch()
 
-
-IVS_PORT_MTU = 9000
-IVS_VM_PORT_PREFIX = 'qvo'
-IVS_VM_PORT_IFACE_PREFIXES = [IVS_VM_PORT_PREFIX, 'qvb', 'tap', 'qbr']
-
 LOG = log.getLogger(__name__)
 
 
-class IVSBridge(object):
-    """IVS Bridge
-
-    This class does not provide parity with OVS using IVS.
-    It's only the bare minimum necessary to use IVS with this agent.
-    """
-    def run_vsctl(self, args, check_error=False, log_fail_as_error=True):
-        full_args = ["ivs-ctl"] + args
-        try:
-            resp = utils.execute(full_args, run_as_root=True,
-                                 return_stderr=True,
-                                 log_fail_as_error=log_fail_as_error)
-            return resp[0] or resp[1]
-        except Exception as e:
-            with excutils.save_and_reraise_exception() as ctxt:
-                if log_fail_as_error:
-                    logfunc = LOG.error
-                else:
-                    logfunc = LOG.debug
-                logfunc("Unable to execute %(cmd)s. "
-                        "Exception: %(exception)s",
-                        {'cmd': full_args, 'exception': e})
-                if not check_error:
-                    ctxt.reraise = False
-
-    def get_vif_port_set(self):
-        port_names = self.get_port_name_list()
-        edge_ports = set(port_names)
-        return edge_ports
-
-    def get_vif_port_by_id(self, port_id):
-        # IVS in nova uses hybrid method with last 11 chars of UUID
-        name = ('qvo%s' % port_id)[:14]
-        if name in self.get_vif_port_set():
-            return name
-        return False
-
-    def get_port_name_list(self):
-        # Try native list-ports command first and then fallback to show
-        # command.
-        try:
-            resp = self.run_vsctl(['list-ports'], True,
-                                  log_fail_as_error=False).strip().splitlines()
-            port_names = [x.strip() for x in resp]
-        except RuntimeError:
-            resp = self.run_vsctl(['show'], True)
-            # get rid of stats and blank lines
-            lines = resp.split('ivs:')[1].split('ports:')[1].splitlines()
-            ports = [x for x in lines if 'packets=' not in x and x.strip()]
-            port_names = [x.strip().split(' ')[1] for x in ports]
-        LOG.debug("Ports on IVS: %s", port_names)
-        return port_names
-
-    def set_port_mtu(self, port_name):
-        # If this IVS port is attached to a VM, set the MTU of all
-        # corresponding interfaces (veth pairs, tap and bridge interfaces)
-        if IVS_VM_PORT_PREFIX in port_name:
-            for iface in IVS_VM_PORT_IFACE_PREFIXES:
-                iface_name = port_name.replace(IVS_VM_PORT_PREFIX, iface)
-                cmd = ['ip', 'link', 'set', iface_name, 'mtu', IVS_PORT_MTU]
-                try:
-                    utils.execute(cmd, run_as_root=True, return_stderr=False,
-                                  log_fail_as_error=False)
-                    LOG.debug("MTU of port %s set to %d", str(iface_name),
-                              IVS_PORT_MTU)
-                except Exception as e:
-                    LOG.error("Set MTU for port %(p)s failed. Unable to "
-                              "execute %(cmd)s. Exception: %(exception)s",
-                              {'p': iface_name, 'cmd': cmd, 'exception': e})
-
-
-class NFVSwitchBridge(object):
-    """NFV Switch Bridge
-
-    This class does not provide parity with OVS using NFVSwitch.
-    It's only the bare minimum necessary to use NFVSwitch with this agent.
-    """
-    def get_vif_port_set(self):
-        # Un-supported operation. Return empty set for no-op
-        return set()
-
-    def get_vif_port_by_id(self, port_id):
-        # Un-supported operation. Return False for no-op
-        return False
-
-
 class FilterDeviceIDMixin(sg_rpc.SecurityGroupAgentRpc):
     """Override SecurityGroupAgentRpc methods that call firewall_driver.
 
@@ -220,18 +127,12 @@ class RestProxyAgent(api_sg_rpc.SecurityGroupAgentRpcCallbackMixin):
 
     target = oslo_messaging.Target(version='1.1')
 
-    def __init__(self, integ_br, polling_interval, vs='ovs'):
+    def __init__(self, integ_br, polling_interval):
         super(RestProxyAgent, self).__init__()
         self.polling_interval = polling_interval
-        if vs == 'ivs':
-            self.int_br = IVSBridge()
-            self.agent_type = "BSN IVS Agent"
-        elif vs == "nfvswitch":
-            self.int_br = NFVSwitchBridge()
-            self.agent_type = "BSN NFVSwitch Agent"
-        else:
-            self.int_br = ovs_lib.OVSBridge(integ_br)
-            self.agent_type = "OVS Agent"
+
+        self.int_br = ovs_lib.OVSBridge(integ_br)
+        self.agent_type = "OVS Agent"
         self.agent_state = {
             'binary': 'neutron-bsn-agent',
             'host': cfg.CONF.host,
@@ -296,13 +197,6 @@ class RestProxyAgent(api_sg_rpc.SecurityGroupAgentRpcCallbackMixin):
                 'added': added,
                 'removed': removed}
 
-    def _update_port_mtus(self, port_info):
-        """Update the MTU of all ports that attach the VM port to IVS """
-        if 'added' in port_info:
-            ports = port_info['added']
-            for port in ports:
-                self.int_br.set_port_mtu(port)
-
     def _process_devices_filter(self, port_info):
         if 'added' in port_info:
             self.sg_agent.prepare_devices_filter(port_info['added'])
@@ -318,7 +212,6 @@ class RestProxyAgent(api_sg_rpc.SecurityGroupAgentRpcCallbackMixin):
                 port_info = self._update_ports(ports)
                 if port_info:
                     LOG.debug("Agent loop has new device")
-                    self._update_port_mtus(port_info)
                     self._process_devices_filter(port_info)
                     ports = port_info['current']
             except Exception:
@@ -341,8 +234,7 @@ def main():
 
     integ_br = cfg.CONF.RESTPROXYAGENT.integration_bridge
     polling_interval = cfg.CONF.RESTPROXYAGENT.polling_interval
-    bsnagent = RestProxyAgent(integ_br, polling_interval,
-                              cfg.CONF.RESTPROXYAGENT.virtual_switch_type)
+    bsnagent = RestProxyAgent(integ_br, polling_interval)
     bsnagent.daemon_loop()
     sys.exit(0)
 
