@@ -59,7 +59,7 @@ class BSNServicePlugin(service_base.ServicePluginBase,
         return 'bsn_service_extension'
 
     def get_plugin_description(self):
-        return "BSN Service Plugin"
+        return "Arista CCF Service Plugin"
 
     # public CRUD methods for network templates
     def get_networktemplates(self, context, filters=None, fields=None,
