@@ -74,7 +74,6 @@ from neutron_lib.agent import topics
 from neutron_lib.api.definitions import allowedaddresspairs as addr_pair
 from neutron_lib.api.definitions import external_net as extnet_apidef
 from neutron_lib.api.definitions import extra_dhcp_opt as edo_ext
-from neutron_lib.api.definitions import l3 as l3_apidef
 from neutron_lib.api.definitions import portbindings
 from neutron_lib import constants as const
 from neutron_lib import context as qcontext
@@ -189,10 +188,6 @@ class NeutronRestProxyV2Base(db_base_plugin_v2.NeutronDbPluginV2,
     def l3_plugin(self):
         return directory.get_plugin(plugin_constants.L3)
 
-    @property
-    def l3_bsn_plugin(self):
-        return hasattr(self.l3_plugin, "bsn")
-
     @property
     def bsn_service_plugin(self):
         return directory.get_plugin(bsn_constants.BSN_SERVICE_PLUGIN)
@@ -231,12 +226,9 @@ class NeutronRestProxyV2Base(db_base_plugin_v2.NeutronDbPluginV2,
 
     def _get_all_data_auto(self):
         return self._get_all_data(
-            get_floating_ips=self.l3_bsn_plugin,
-            get_routers=self.l3_bsn_plugin,
             get_sgs=cfg.CONF.RESTPROXY.sync_security_groups)
 
-    def _get_all_data(self, get_ports=True, get_floating_ips=True,
-                      get_routers=True, get_sgs=True):
+    def _get_all_data(self, get_ports=True, get_sgs=True):
         # sync tenant cache with keystone
         if not self.servers._update_tenant_cache(reconcile=False):
             return None
@@ -266,11 +258,7 @@ class NeutronRestProxyV2Base(db_base_plugin_v2.NeutronDbPluginV2,
                         new_subnets.append(subnet)
                     mapped_network['subnets'] = new_subnets
 
-                if get_floating_ips:
-                    flips_n_ports = self._get_network_with_floatingips(
-                        mapped_network)
-                else:
-                    flips_n_ports = mapped_network
+                networks_n_ports = mapped_network
 
                 if get_ports:
                     ports = []
@@ -280,13 +268,7 @@ class NeutronRestProxyV2Base(db_base_plugin_v2.NeutronDbPluginV2,
                     for port in net_ports:
                         if not self._is_port_supported(port):
                             continue
-                        # skip L3 router ports since the backend
-                        # implements the router
-                        if (self.l3_bsn_plugin and
-                            port.get('device_owner') in
-                            [const.DEVICE_OWNER_ROUTER_GW,
-                             const.DEVICE_OWNER_ROUTER_HA_INTF]):
-                            continue
+
                         mapped_port = self._map_display_name_or_tenant(port)
                         if self.servers.is_unicode_enabled():
                             # remove port name so that it won't be stored in
@@ -308,78 +290,16 @@ class NeutronRestProxyV2Base(db_base_plugin_v2.NeutronDbPluginV2,
 
                         ports.append(mapped_port)
 
-                    flips_n_ports['ports'] = ports
+                    networks_n_ports['ports'] = ports
 
-                if flips_n_ports:
-                    networks.append(flips_n_ports)
+                if networks_n_ports:
+                    networks.append(networks_n_ports)
             except servermanager.TenantIDNotFound:
                 # if tenant name is not known to keystone, skip the network
                 continue
 
         data = {'networks': networks}
 
-        if get_routers and self.l3_plugin:
-            routers = []
-            all_routers = self.l3_plugin.get_routers(admin_context) or []
-            all_policies = (self.bsn_service_plugin
-                            .get_tenantpolicies(admin_context)
-                            if self.bsn_service_plugin else [])
-            tenant_policies = {}
-            for policy in all_policies:
-                if policy['tenant_id'] not in tenant_policies:
-                    tenant_policies[policy['tenant_id']] = []
-                policy['ipproto'] = policy['protocol']
-                tenant_policies[policy['tenant_id']].append(policy)
-            for router in all_routers:
-                try:
-                    # Add tenant_id of the external gateway network
-                    if router.get(l3_apidef.EXTERNAL_GW_INFO):
-                        ext_net_id = router[l3_apidef.EXTERNAL_GW_INFO].get(
-                            'network_id')
-                        ext_net = self.get_network(admin_context, ext_net_id)
-                        ext_tenant_id = ext_net.get('tenant_id')
-                        if ext_tenant_id:
-                            router[l3_apidef.EXTERNAL_GW_INFO]['tenant_id'] = (
-                                ext_tenant_id)
-
-                    interfaces = []
-                    mapped_router = self._map_display_name_or_tenant(router)
-                    mapped_router = self._map_state_and_status(mapped_router)
-                    if not self._validate_names(mapped_router):
-                        continue
-
-                    router_filter = {
-                        'device_owner': [const.DEVICE_OWNER_ROUTER_INTF],
-                        'device_id': [router.get('id')]
-                    }
-                    router_ports = self.get_ports(admin_context,
-                                                  filters=router_filter) or []
-                    for port in router_ports:
-
-                        for fixed_ip in port['fixed_ips']:
-                            subnet_id = fixed_ip['subnet_id']
-                            intf_details = self._get_router_intf_details(
-                                admin_context, port, subnet_id)
-
-                            interfaces.append(intf_details)
-
-                    mapped_router['interfaces'] = interfaces
-
-                    routers.append(mapped_router)
-                except servermanager.TenantIDNotFound:
-                    # if tenant name is not known to keystone, skip the network
-                    continue
-
-            # append router_tenant_rules to each router
-            for router in routers:
-                if router['tenant_id'] in tenant_policies:
-                    router['policies'] = tenant_policies[router['tenant_id']]
-
-            data.update({'routers': routers})
-
-            # L3 plugin also includes tenant policies
-            # data.update({'policies': tenant_policies})
-
         if get_sgs and self.l3_plugin:
             sgs = plugin.get_security_groups(admin_context) or []
             new_sgs = []
@@ -428,13 +348,11 @@ class NeutronRestProxyV2Base(db_base_plugin_v2.NeutronDbPluginV2,
 
     def _send_all_data_auto(self, timeout=None, triggered_by_tenant=None):
         return self._send_all_data(
-            send_floating_ips=self.l3_bsn_plugin,
-            send_routers=self.l3_bsn_plugin,
             timeout=timeout,
             triggered_by_tenant=triggered_by_tenant)
 
-    def _send_all_data(self, send_ports=True, send_floating_ips=True,
-                       send_routers=True, send_sgs=True, timeout=None,
+    def _send_all_data(self, send_ports=True,
+                       send_sgs=True, timeout=None,
                        triggered_by_tenant=None):
         """Pushes all data to network ctrl (networks/ports, ports/attachments).
 
@@ -442,7 +360,7 @@ class NeutronRestProxyV2Base(db_base_plugin_v2.NeutronDbPluginV2,
         with neutron's current view of that data.
 
         All args are ignored. The `_get_all_data` method dynamically pulls the
-        relevant information i.e. if its L2 only or L2+L3.
+        relevant information i.e. starting from train, this supports l2 only
         """
         sync_executed, topo_resp = self.servers.force_topo_sync()
         return topo_resp
@@ -456,38 +374,6 @@ class NeutronRestProxyV2Base(db_base_plugin_v2.NeutronDbPluginV2,
                 # resource name may contain space. Replace space with -
                 resource['name'] = Util.format_resource_name(resource['name'])
 
-    def _get_network_with_floatingips(self, network, context=None):
-        if context is None:
-            context = qcontext.get_admin_context()
-
-        net_id = network['id']
-        net_filter = {'floating_network_id': [net_id]}
-        if self.l3_plugin:
-            fl_ips = self.l3_plugin.get_floatingips(context,
-                                                    filters=net_filter) or []
-            floating_ips = []
-            for flip in fl_ips:
-                try:
-                    # BVS-7525: the 'tenant_id' in a floating-ip represents the
-                    # tenant to which it is allocated.
-                    # Validate that the tenant exists
-                    # name/display-name of floating ip is not actually
-                    # used on bcf
-                    mapped_flip = self._map_display_name_or_tenant(flip)
-                    if mapped_flip.get('floating_port_id'):
-                        fport = self.get_port(context,
-                                              mapped_flip['floating_port_id'])
-                        mapped_flip['floating_mac_address'] = \
-                            fport.get('mac_address')
-                    floating_ips.append(mapped_flip)
-                except servermanager.TenantIDNotFound:
-                    # if tenant name is not known to keystone, skip it
-                    continue
-
-            network['floatingips'] = floating_ips
-
-        return network
-
     def _get_all_subnets_json_for_network(self, net_id, context=None):
         if context is None:
             context = qcontext.get_admin_context()
@@ -604,7 +490,7 @@ class NeutronRestProxyV2Base(db_base_plugin_v2.NeutronDbPluginV2,
     def _send_create_network(self, network, context=None):
         tenant_id = network['tenant_id']
         if self._skip_bcf_network_event(network):
-            LOG.info('Skipping BCF segment create for Network: %(name)s',
+            LOG.info('Skipping CCF segment create for Network: %(name)s',
                      {'name': network.get('name')})
             return
 
@@ -635,7 +521,7 @@ class NeutronRestProxyV2Base(db_base_plugin_v2.NeutronDbPluginV2,
         net_id = network['id']
         tenant_id = network['tenant_id']
         if self._skip_bcf_network_event(network):
-            LOG.info('Skipping BCF segment update for Network: %(name)s',
+            LOG.info('Skipping CCF segment update for Network: %(name)s',
                      {'name': network.get('name')})
             return
 
@@ -643,19 +529,13 @@ class NeutronRestProxyV2Base(db_base_plugin_v2.NeutronDbPluginV2,
         mapped_network = self._get_mapped_network_with_subnets(network,
                                                                context)
 
-        if self.l3_bsn_plugin:
-            net_fl_ips = self._get_network_with_floatingips(mapped_network,
-                                                            context)
-        else:
-            net_fl_ips = mapped_network
-
         if not tenant_id:
             tenant_id = servermanager.SERVICE_TENANT
-            net_fl_ips['tenant_id'] = servermanager.SERVICE_TENANT
+            mapped_network['tenant_id'] = servermanager.SERVICE_TENANT
             if not self.servers.is_unicode_enabled():
-                net_fl_ips['name'] = Util.format_resource_name(
-                    net_fl_ips['name'])
-        self.servers.rest_update_network(tenant_id, net_id, net_fl_ips)
+                mapped_network['name'] = Util.format_resource_name(
+                    mapped_network['name'])
+        self.servers.rest_update_network(tenant_id, net_id, mapped_network)
 
     def _send_delete_network(self, network, context=None):
         net_id = network['id']
@@ -894,8 +774,7 @@ class NeutronRestProxyV2Base(db_base_plugin_v2.NeutronDbPluginV2,
 
     def _extend_port_dict_binding(self, context, port):
         cfg_vif_type = cfg.CONF.NOVA.vif_type.lower()
-        if cfg_vif_type not in (portbindings.VIF_TYPE_OVS,
-                                pl_config.VIF_TYPE_IVS):
+        if cfg_vif_type not in (portbindings.VIF_TYPE_OVS):
             LOG.warning("Unrecognized vif_type in configuration "
                         "[%s]. Defaulting to ovs.",
                         cfg_vif_type)
@@ -1346,7 +1225,7 @@ class NeutronRestProxyV2(NeutronRestProxyV2Base,
         :raises: RemoteRestError
         """
         # if needed, check to see if this is a port owned by
-        # and l3-router.  If so, we should prevent deletion.
+        # an l3-router.  If so, we should prevent deletion.
         if l3_port_check and self.l3_plugin:
             self.l3_plugin.prevent_l3_port_deletion(context, port_id)
         with db_api.CONTEXT_WRITER.using(context):
