@@ -164,7 +164,7 @@ class NetworkNameChangeError(exceptions.NeutronException):
 
 
 class RemoteRestError(exceptions.NeutronException):
-    message = _("Error in REST call to BCF "
+    message = _("Error in REST call to CCF "
                 "controller: %(reason)s")
     status = None
 
@@ -430,7 +430,7 @@ class ServerProxy(object):
             respstr = response.read()
             respdata = respstr
             bcf_response_time = time.time()
-            LOG.debug("Time waited to get response from BCF %.2fsecs",
+            LOG.debug("Time waited to get response from CCF %.2fsecs",
                       (bcf_response_time - bcf_request_time))
             if response.status in self.success_codes:
                 try:
@@ -634,7 +634,7 @@ class ServerPool(object):
                                      self.state_sync_interval)
                 LOG.info('Orchestrator State Sync is enabled.')
             else:
-                LOG.info('BCF does not support orchestrator-state-sync, '
+                LOG.info('CCF does not support orchestrator-state-sync, '
                          'disabled it.')
         else:
             LOG.info('Orchestrator State Sync is disabled.')
@@ -701,7 +701,7 @@ class ServerPool(object):
         # unicode enabled, but not supported by controller
         else:
             LOG.warning('naming_scheme_unicode is set to True,'
-                        ' but BCF does not support it.'
+                        ' but CCF does not support it.'
                         ' Unicode names Disabled')
 
     def is_unicode_enabled(self):
@@ -712,7 +712,7 @@ class ServerPool(object):
         """
         LOG.debug('Current Capabilities: %s', self.get_capabilities())
         if not self.get_capabilities():
-            msg = 'Capabilities unknown! Please check BCF controller status.'
+            msg = 'Capabilities unknown! Please check CCF controller status.'
             raise RemoteRestError(reason=msg)
 
         if self.cfg_unicode_enabled and 'display-name' in \
@@ -1245,7 +1245,7 @@ class ServerPool(object):
                 # that is wrong, we need to raise an exception
                 raise Exception(_("TOPO_SYNC: failed to retrieve data."))
             LOG.debug("TOPO_SYNC: data received from OSP, sending "
-                      "request to BCF.")
+                      "request to CCF.")
             errstr = _("Unable to perform forced topology_sync: %s")
             return True, self.rest_action('POST', TOPOLOGY_PATH, data, errstr)
         except Exception as e:
