@@ -13,8 +13,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 import copy
-import datetime
-import os
 
 import eventlet
 
@@ -23,7 +21,6 @@ from neutron_lib.api.definitions import portbindings
 from neutron_lib.callbacks import events
 from neutron_lib.callbacks import registry
 from neutron_lib.callbacks import resources
-from neutron_lib import constants as const
 from neutron_lib import context as ctx
 from neutron_lib.plugins import directory
 from neutron_lib.plugins.ml2 import api
@@ -32,12 +29,9 @@ from oslo_config import cfg
 from oslo_log import log
 import oslo_messaging
 from oslo_utils import excutils
-from oslo_utils import timeutils
 from six.moves import http_client
 
 from networking_bigswitch.plugins.bigswitch import config as pl_config
-from networking_bigswitch.plugins.bigswitch import constants as bsn_consts
-from networking_bigswitch.plugins.bigswitch.i18n import _
 from networking_bigswitch.plugins.bigswitch.i18n import _LE
 from networking_bigswitch.plugins.bigswitch.i18n import _LW
 from networking_bigswitch.plugins.bigswitch import plugin
@@ -81,13 +75,12 @@ class BigSwitchMechanismDriver(plugin.NeutronRestProxyV2Base,
                              **{'check_ts': True})
 
         self.segmentation_types = ', '.join(cfg.CONF.ml2.type_drivers)
-        # if os-net-config is present, attempt to read physnet bridge_mappings
+        # if it is RH system, attempt to read physnet bridge_mappings
         # from openvswitch_agent.ini
         self.bridge_mappings = {}
-        if os.path.isfile(bsn_consts.RH_NET_CONF_PATH):
+        if Util.is_redhat():
             self.bridge_mappings = Util.read_ovs_bridge_mappings()
-        # Track hosts running IVS to avoid excessive calls to the backend
-        self.ivs_host_cache = {}
+
         self.setup_rpc_callbacks()
 
         LOG.debug("Initialization done")
@@ -169,11 +162,11 @@ class BigSwitchMechanismDriver(plugin.NeutronRestProxyV2Base,
             self.bsn_create_security_group(sg_id=sg_id, context=context)
 
     def bsn_delete_sg_rule(self, sg_rule, context):
-        LOG.debug("Deleting security group rule from BCF: %s", sg_rule)
+        LOG.debug("Deleting security group rule from CCF: %s", sg_rule)
         if not context:
             LOG.error(_LE(
                 "Context missing when trying to delete security group rule. "
-                "Please force-bcf-sync to ensure consistency with BCF."))
+                "Please force-ccf-sync to ensure consistency with CCF."))
         sg_id = sg_rule['security_group_id']
         # we over write the sg on bcf controller instead of deleting
         try:
@@ -280,13 +273,6 @@ class BigSwitchMechanismDriver(plugin.NeutronRestProxyV2Base,
             LOG.debug("SR-IOV port, nothing to do")
             return
 
-        # If bsn_l3 plugin and it is a gateway port, bind to ivs.
-        if (self.l3_bsn_plugin and
-                context.current['device_owner'] == ROUTER_GATEWAY_PORT_OWNER):
-            directory.get_plugin().update_port_status(
-                context._plugin_context, context.current['id'],
-                const.PORT_STATUS_ACTIVE)
-
         try:
             # create port on the network controller
             port = self._prepare_port_for_controller(context)
@@ -383,89 +369,3 @@ class BigSwitchMechanismDriver(plugin.NeutronRestProxyV2Base,
         prepped_port = self._map_state_and_status(prepped_port)
         prepped_port = self._map_port_hostid(prepped_port, net)
         return prepped_port
-
-    def _bind_port_ivswitch(self, context, segment):
-        """Perform bind_port for Indigo virtual switch.
-
-        @param context: PortContext object
-        """
-        vif_type = pl_config.VIF_TYPE_IVS
-        vif_details = {portbindings.CAP_PORT_FILTER: True,
-                       portbindings.OVS_HYBRID_PLUG: True}
-        context.set_binding(segment[api.ID], vif_type, vif_details)
-
-    @add_debug_log
-    def bind_port(self, context):
-        """Marks ports as bound.
-
-        Binds external ports and IVS ports.
-        Fabric configuration will occur on the subsequent port update.
-        Currently only vlan segments are supported.
-        """
-        if context.current['device_owner'] == EXTERNAL_PORT_OWNER:
-            # TODO(kevinbenton): check controller to see if the port exists
-            # so this driver can be run in parallel with others that add
-            # support for external port bindings
-            for segment in context.segments_to_bind:
-                if segment[api.NETWORK_TYPE] == const.TYPE_VLAN:
-                    context.set_binding(
-                        segment[api.ID], portbindings.VIF_TYPE_BRIDGE,
-                        {portbindings.CAP_PORT_FILTER: False,
-                         portbindings.OVS_HYBRID_PLUG: False})
-                    return
-
-        if not self._is_port_supported(context.current):
-            LOG.debug("Ignoring unsupported vnic type")
-            return
-
-        if self._is_port_sriov(context.current):
-            LOG.debug("SR-IOV port, nothing to do")
-            return
-
-        # IVS hosts will have a vswitch with the same name as the hostname
-        if self.does_vswitch_exist(context.host):
-            for segment in context.segments_to_bind:
-                if segment[api.NETWORK_TYPE] == const.TYPE_VLAN:
-                    self._bind_port_ivswitch(context, segment)
-
-    def does_vswitch_exist(self, host):
-        """Check if Indigo vswitch exists with the given hostname.
-
-        Returns True if switch exists on backend.
-        Returns False if switch does not exist.
-        Returns None if backend could not be reached.
-        Caches response from backend.
-        """
-        try:
-            return self._get_cached_vswitch_existence(host)
-        except ValueError:
-            # cache was empty for that switch or expired
-            pass
-
-        try:
-            exists = bool(self.servers.rest_get_switch(host))
-        except servermanager.RemoteRestError:
-            # Connectivity or internal server error. Skip cache to try again on
-            # next binding attempt
-            return
-        self.ivs_host_cache[host] = {
-            'timestamp': datetime.datetime.now(),
-            'exists': exists
-        }
-        return exists
-
-    def _get_cached_vswitch_existence(self, host):
-        """Returns cached existence.
-
-        Expired and non-cached raise ValueError.
-        """
-        entry = self.ivs_host_cache.get(host)
-        if not entry:
-            raise ValueError(_('No cache entry for host %s') % host)
-
-        diff = timeutils.delta_seconds(entry['timestamp'],
-                                       datetime.datetime.now())
-        if diff > CACHE_VSWITCH_TIME:
-            self.ivs_host_cache.pop(host)
-            raise ValueError(_('Expired cache entry for host %s') % host)
-        return entry['exists']
