@@ -28,7 +28,6 @@ from oslo_config import cfg
 import webob.exc
 
 # from networking_bigswitch.plugins.bigswitch import config as pl_config
-from networking_bigswitch.plugins.bigswitch import constants as bsn_constants
 from networking_bigswitch.plugins.bigswitch.servermanager import \
     TenantIDNotFound
 from networking_bigswitch.tests.unit.bigswitch import fake_server
@@ -50,13 +49,6 @@ class BigSwitchProxyPluginV2TestCase(bsn_test_base.BigSwitchTestBase,
         self.setup_patches()
         if plugin_name:
             self._plugin_name = plugin_name
-        bsn_service_plugins = {'L3_ROUTER_NAT': self._l3_plugin_name,
-                               bsn_constants.BSN_SERVICE_PLUGIN:
-                                   self._bsn_service_plugin_name}
-        if service_plugins:
-            service_plugins.update(bsn_service_plugins)
-        else:
-            service_plugins = bsn_service_plugins
 
         test_plugin.NeutronDbPluginV2TestCase.setUp(
             self, self._plugin_name,
@@ -270,11 +262,11 @@ class TestVifDifferentDefault(BigSwitchProxyPluginV2TestCase):
 
     def setup_config_files(self):
         super(TestVifDifferentDefault, self).setup_config_files()
-        cfg.CONF.set_override('vif_type', 'ivs', 'NOVA')
+        cfg.CONF.set_override('vif_type', 'ovs', 'NOVA')
 
     def test_default_viftype(self):
         with self.port() as port:
-            self.assertEqual(port['port']['binding:vif_type'], 'ivs')
+            self.assertEqual(port['port']['binding:vif_type'], 'ovs')
 
 
 class TestBigSwitchProxyNetworksV2(test_plugin.TestNetworksV2,
