@@ -401,7 +401,7 @@ class ServerManagerTests(test_rp.BigSwitchProxyPluginV2TestCase):
                               pl.servers.rest_action,
                               **{'action': 'DELETE', 'resource': '/',
                                  'data': '',
-                                 'errstr': "Unable to DELETE query to BCF: %s",
+                                 'errstr': "Unable to DELETE query to CCF: %s",
                                  'ignore_codes': []})
             topo_mock.assert_called_once_with(**{'check_ts': True})
 
@@ -419,7 +419,7 @@ class ServerManagerTests(test_rp.BigSwitchProxyPluginV2TestCase):
             self.assertRaises(servermanager.RemoteRestError,
                               pl.servers.rest_action,
                               **{'action': 'POST', 'resource': '/', 'data': '',
-                                 'errstr': "Unable to POST query to BCF: %s",
+                                 'errstr': "Unable to POST query to CCF: %s",
                                  'ignore_codes': []})
             topo_mock.assert_called_once_with(**{'check_ts': True})
 
